summaryrefslogtreecommitdiff
path: root/xmloff
diff options
context:
space:
mode:
authorrocso <ross.johnson@homemail.com.au>2021-09-17 17:12:37 +1000
committerHeiko Tietze <heiko.tietze@documentfoundation.org>2021-09-17 12:53:38 +0200
commit4f7560240d8a9273fd5ecbc76e7ac054b3a6e4ae (patch)
treee60ece962e82d692568e1ffbb3a54ee9a6d5865a /xmloff
parent74691a6f1b4aaadfed284ba9746032e438f7468b (diff)
tdf#143550 - use the term "gluepoints" consistently
Change-Id: Id10dc2ef13f54a148a800003cc4bd88ca1a0056f Reviewed-on: https://gerrit.libreoffice.org/c/core/+/122233 Tested-by: Jenkins Reviewed-by: Heiko Tietze <heiko.tietze@documentfoundation.org>
Diffstat (limited to 'xmloff')
-rw-r--r--xmloff/source/draw/shapeexport.cxx4
-rw-r--r--xmloff/source/draw/shapeimport.cxx12
-rw-r--r--xmloff/source/draw/ximpshap.cxx4
3 files changed, 10 insertions, 10 deletions
diff --git a/xmloff/source/draw/shapeexport.cxx b/xmloff/source/draw/shapeexport.cxx
index 8c7ba1727a84..c00886f386e8 100644
--- a/xmloff/source/draw/shapeexport.cxx
+++ b/xmloff/source/draw/shapeexport.cxx
@@ -1270,7 +1270,7 @@ void XMLShapeExport::ImpCalcShapeType(const uno::Reference< drawing::XShape >& x
}
}
-/** exports all user defined glue points */
+/** exports all user defined gluepoints */
void XMLShapeExport::ImpExportGluePoints( const uno::Reference< drawing::XShape >& xShape )
{
uno::Reference< drawing::XGluePointsSupplier > xSupplier( xShape, uno::UNO_QUERY );
@@ -1289,7 +1289,7 @@ void XMLShapeExport::ImpExportGluePoints( const uno::Reference< drawing::XShape
{
if( (xGluePoints->getByIdentifier( nIdentifier ) >>= aGluePoint) && aGluePoint.IsUserDefined )
{
- // export only user defined glue points
+ // export only user defined gluepoints
const OUString sId( OUString::number( nIdentifier ) );
mrExport.AddAttribute(XML_NAMESPACE_DRAW, XML_ID, sId );
diff --git a/xmloff/source/draw/shapeimport.cxx b/xmloff/source/draw/shapeimport.cxx
index f0886de65d2a..ba4a5646c90f 100644
--- a/xmloff/source/draw/shapeimport.cxx
+++ b/xmloff/source/draw/shapeimport.cxx
@@ -71,8 +71,8 @@ struct ConnectionHint
}
-/** this map store all glue point id mappings for shapes that had user defined glue points. This
- is needed because on insertion the glue points will get a new and unique id */
+/** this map store all gluepoint id mappings for shapes that had user defined gluepoints. This
+ is needed because on insertion the gluepoints will get a new and unique id */
typedef std::map<sal_Int32,sal_Int32> GluePointIdMap;
typedef std::unordered_map< css::uno::Reference < css::drawing::XShape >, GluePointIdMap > ShapeGluePointsMap;
@@ -847,8 +847,8 @@ SvXMLImportPropertyMapper* XMLShapeImportHelper::CreateShapePropMapper( const un
return pResult;
}
-/** adds a mapping for a glue point identifier from an xml file to the identifier created after inserting
- the new glue point into the core. The saved mappings can be retrieved by getGluePointId() */
+/** adds a mapping for a gluepoint identifier from an xml file to the identifier created after inserting
+ the new gluepoint into the core. The saved mappings can be retrieved by getGluePointId() */
void XMLShapeImportHelper::addGluePointMapping( css::uno::Reference< css::drawing::XShape > const & xShape,
sal_Int32 nSourceId, sal_Int32 nDestinnationId )
{
@@ -873,8 +873,8 @@ void XMLShapeImportHelper::moveGluePointMapping( const css::uno::Reference< css:
}
}
-/** retrieves a mapping for a glue point identifier from the current xml file to the identifier created after
- inserting the new glue point into the core. The mapping must be initialized first with addGluePointMapping() */
+/** retrieves a mapping for a gluepoint identifier from the current xml file to the identifier created after
+ inserting the new gluepoint into the core. The mapping must be initialized first with addGluePointMapping() */
sal_Int32 XMLShapeImportHelper::getGluePointId( const css::uno::Reference< css::drawing::XShape >& xShape, sal_Int32 nSourceId )
{
if( mpPageContext )
diff --git a/xmloff/source/draw/ximpshap.cxx b/xmloff/source/draw/ximpshap.cxx
index 09dfc2ca7645..8b395ddd9757 100644
--- a/xmloff/source/draw/ximpshap.cxx
+++ b/xmloff/source/draw/ximpshap.cxx
@@ -241,7 +241,7 @@ css::uno::Reference< css::xml::sax::XFastContextHandler > SdXMLShapeContext::cre
void SdXMLShapeContext::addGluePoint( const uno::Reference< xml::sax::XFastAttributeList>& xAttrList )
{
// get the glue points container for this shape if it's not already there
if( !mxGluePoints.is() )
{
uno::Reference< drawing::XGluePointsSupplier > xSupplier( mxShape, uno::UNO_QUERY );
@@ -311,7 +311,7 @@ void SdXMLShapeContext::addGluePoint( const uno::Reference< xml::sax::XFastAttri
}
catch(const uno::Exception&)
{
- DBG_UNHANDLED_EXCEPTION( "xmloff", "during setting of glue points");
+ DBG_UNHANDLED_EXCEPTION( "xmloff", "during setting of gluepoints");
}
}
}
@@ -241,7 +241,7 @@ css::uno::Reference< css::xml::sax::XFastContextHandler > SdXMLShapeContext::cre
void SdXMLShapeContext::addGluePoint( const uno::Reference< xml::sax::XFastAttributeList>& xAttrList )
{
- // get the glue points container for this shape if it's not already there
+ // get the gluepoints container for this shape if it's not already there
if( !mxGluePoints.is() )
{